@@ -101,6 +101,7 @@ sub _got_data {
             # output to build an amc-item.
             my ($k,$v) = split /:\s+/, $input, 2;
             $k = lc $k;
+            $k =~ s/-/_/;
 
             if ( $k eq 'file' || $k eq 'directory' || $k eq 'playlist' ) {
                 # build a new amc-item
@@ -475,7 +476,7 @@ answered with the error message C<$errstr>.
 =head1 SEE ALSO
 
 For all related information (bug reporting, mailing-list, pointers to
-MPD and POE, etc.), refer to C<POE::Component::Client::MPD>'s pod,
+MPD and POE, etc.), refer to L<POE::Component::Client::MPD>'s pod,
 section C<SEE ALSO>
 
 
