@@ -1,6 +1,6 @@
 #
 # This file is part of POE::Component::Client::MPD.
-# Copyright (c) 2007 Jerome Quelin, all rights reserved.
+# Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -14,12 +14,17 @@ use warnings;
 
 use Readonly;
 
-use base qw[ Class::Accessor::Fast Exporter ];
-__PACKAGE__->mk_accessors( qw[
-    data error request
-    _answer _commands _cooking _transform _from _request _dispatch _params
-    _post _pre_event _pre_from _pre_data _post_to _post_event
-] );
+use base qw{ Exporter Class::Accessor::Fast };
+__PACKAGE__->mk_accessors( qw{
+    request params status
+    _data _commands _cooking _transform _post _from
+} );
+
+our @EXPORT = qw{
+    $SEND $DISCARD $SLEEP1
+    $RAW $AS_ITEMS $AS_KV $STRIP_FIRST
+    $AS_SCALAR $AS_STATS $AS_STATUS
+};
 
 
 # constants for _answer
@@ -34,18 +39,11 @@ Readonly our $AS_KV       => 2; # data is to be returned as kv (hash)
 Readonly our $STRIP_FIRST => 3; # data should have its first field stripped
 
 # constants for _transform
-Readonly our $AS_SCALAR => 0; # transform data from list to scalar
-Readonly our $AS_STATS  => 1; # transform data from kv to amc-stats
-Readonly our $AS_STATUS => 2; # transform data from kv to amc-status
+Readonly our $AS_SCALAR => 0; # transform data: return first elem instead of full list
+Readonly our $AS_STATS  => 1; # transform data: from kv to amc-stats
+Readonly our $AS_STATUS => 2; # transform data: from kv to amc-status
 
 
-our @EXPORT = qw[
-    $SEND $DISCARD $SLEEP1
-    $RAW $AS_ITEMS $AS_KV $STRIP_FIRST
-    $AS_SCALAR $AS_STATS $AS_STATUS
-];
-
-#our ($VERSION) = '$Rev: 5645 $' =~ /(\d+)/;
 
 1;
 
@@ -63,8 +61,8 @@ POE::Component::Client::MPD::Message - a message from POCOCM
 
 =head1 DESCRIPTION
 
-C<POCOCM::Message> is more a placeholder for a hash ref with some pre-defined
-keys.
+L<POE::Component::Client::MPD::Message> is more a placeholder for a hash
+ref with some pre-defined keys.
 
 
 =head1 PUBLIC METHODS
@@ -76,15 +74,19 @@ The other public methods are the following accessors:
 
 =over 4
 
-=item * data()
+=item * request()
 
-The data returned by mpd, as an array reference.
+The event sent to POCOCM.
 
 
-=item * error()
+=item * params()
 
-Set if there was some error returned by mpd. Always assured to be C<undef>
-if everything went fine.
+The params of the event to POCOCM, as sent by client.
+
+
+=item * status()
+
+The status of the request. True for success, False in case of error.
 
 
 =back
@@ -94,18 +96,18 @@ if everything went fine.
 =head1 SEE ALSO
 
 For all related information (bug reporting, mailing-list, pointers to
-MPD and POE, etc.), refer to C<POE::Component::Client::MPD>'s pod,
+MPD and POE, etc.), refer to L<POE::Component::Client::MPD>'s pod,
 section C<SEE ALSO>
 
 
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin at cpan.org> >>
+Jerome Quelin, C<< <jquelin@cpan.org> >>
 
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2007 Jerome Quelin, all rights reserved.
+Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
